NAME

Tk::DataControl - Record Navigation Widget

SYNOPSIS

$datacontrol = $parent->DataControl(?options?);

STRANDARD OPTIONS

-background | -bg, -foreground | -fg, -state, -width, -height, -relief, -cursor, -borderwidth,

WIDGET SPECIFIC OPTIONS

    Name   :  dbh 

    Class  :  Dbh 

    Switch :  -dbh

         Specify the valid DataBase Handle

    Name   :  table 

    Class  :  Table 

    Switch :  -table

         Specify the Table to Navigate the Records

    Name   :  fieldlist 

    Class  :  FieldList 

    Switch :  -fieldlist

         The Array reference of list of fields from table to display

    Name   :  textlist 

    Class  :  TextList 

    Switch :  -textlist

         The Array reference of list of Textbox(Entry) Widget
	
    Name   :  beep

    Class  :  Beep

    Switch :  -beep

         Specifies whether to enable bell when reaches the Boundary while Navigation.
	

DESCRIPTION

A DataControl Navigation Control for Records From the Table

Example

#! /usr/bin/perl -w
use Tk;
use DataControl;
use DBI;

my $mw = MainWindow->new();
my $text1 = $mw->Entry()->pack;
my $text2 = $mw->Entry()->pack;
my $dbh = DBI->connect("dbi:?driver?:dbname=?dbaname?", "?username?", "?password?");
my $dc = $mw->DataControl
  (
   -dbh => $dbh, 
   -table => '?table_name?', 
   -textlist => [$text1, $text2], 
   -fieldlist => ['?field1?', '?field2?'], 
   -foreground => 'blue'
  );

$dc->pack();

MainLoop;

AUTHORS

SanjaySen , palash_bksys@yahoo.com

1 POD Error

The following errors were encountered while parsing the POD:

Around line 866:

=cut found outside a pod block. Skipping to next block.